@@ -40,7 +40,7 @@
 #ifdef	DOSCCS
 static char copyright[]
 = "@(#) Copyright (c) 2000, 2002 Gunnar Ritter. All rights reserved.\n";
-static char sccsid[]  = "@(#)mime.c	2.64 (gritter) 3/4/06";
+static char sccsid[]  = "@(#)mime.c	2.68 (gritter) 6/16/07";
 #endif /* DOSCCS */
 #endif /* not lint */
 
@@ -720,7 +720,7 @@ static enum mimeclean
 mime_isclean(FILE *f)
 {
 	long initial_pos;
-	unsigned curlen = 1, maxlen = 0, limit = -1;
+	unsigned curlen = 1, maxlen = 0, limit = 950;
 	enum mimeclean isclean = 0;
 	char	*cp;
 	int c = EOF, lastc;
@@ -792,7 +792,9 @@ get_mime_convert(FILE *fp, char **contenttype, char **charset,
 	int convert;
 
 	*isclean = mime_isclean(fp);
-	if (*isclean & (MIME_HASNUL)) {
+	if (*isclean & MIME_HASNUL ||
+			*contenttype && ascncasecmp(*contenttype, "text/", 5) ||
+			*contenttype == NULL && *isclean & MIME_CTRLCHAR) {
 		convert = CONV_TOB64;
 		if (*contenttype == NULL ||
 				ascncasecmp(*contenttype, "text/", 5) == 0)
@@ -1049,6 +1051,7 @@ mime_fromhdr(struct str *in, struct str *out, enum tdflags flags)
 				if (iconv_ft(fhicd, &iptr, &inleft,
 						&nptr, &outleft) != 0 &&
 						errno == E2BIG) {
+					iconv(fhicd, NULL, NULL, NULL, NULL);
 					mime_fromhdr_inc(inleft);
 					goto again;
 				}
@@ -1489,6 +1492,7 @@ fwrite_td(void *ptr, size_t size, size_t nmemb, FILE *f, enum tdflags flags,
 		iptr = ptr;
 		if (iconv_ft(iconvd, &iptr, &inleft, &nptr, &outleft) != 0 &&
 				errno == E2BIG) {
+			iconv(iconvd, NULL, NULL, NULL, NULL);
 			ac_free(mptr);
 			mptrsz += inleft;
 			mptr = ac_alloc(mptrsz + 1);
@@ -1525,9 +1529,10 @@ fwrite_td(void *ptr, size_t size, size_t nmemb, FILE *f, enum tdflags flags,
  * fwrite performing the given MIME conversion.
  */
 size_t
-mime_write(void *ptr, size_t size, size_t nmemb, FILE *f,
+mime_write(void *ptr, size_t size, FILE *f,
 		enum conversion convert, enum tdflags dflags,
-		char *prefix, size_t prefixlen)
+		char *prefix, size_t prefixlen,
+		char **restp, size_t *restsizep)
 {
 	struct str in, out;
 	size_t sz, csize;
@@ -1538,9 +1543,9 @@ mime_write(void *ptr, size_t size, size_t nmemb, FILE *f,
 	size_t inleft, outleft;
 #endif
 
-	if (size == 0 || nmemb == 0)
+	if (size == 0)
 		return 0;
-	csize = size * nmemb / sizeof (char);
+	csize = size;
 #ifdef	HAVE_ICONV
 	if (csize < sizeof mptr && (dflags & TD_ICONV)
 			&& iconvd != (iconv_t)-1
@@ -1586,8 +1591,14 @@ mime_write(void *ptr, size_t size, size_t nmemb, FILE *f,
 		/*FALLTHROUGH*/
 	case CONV_FROMB64:
 		mime_fromb64_b(&in, &out, is_text, f);
-		sz = fwrite_td(out.s, sizeof *out.s, out.l, f, dflags,
+		if (is_text && out.s[out.l-1] != '\n' && restp && restsizep) {
+			*restp = ptr;
+			*restsizep = size;
+			sz = 0;
+		} else {
+			sz = fwrite_td(out.s, sizeof *out.s, out.l, f, dflags,
 				prefix, prefixlen);
+		}
 		free(out.s);
 		break;
 	case CONV_TOB64:
